@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -228,6 +228,21 @@ sub isHDMI {
     return $io->readHDMI(0x05) & 0x80;
 }
 
+sub isDERegenFilterLocked {
+    my ($io) = @_;
+    return $io->readHDMI(0x07) & 0x20;
+}
+
+sub isVertFilterLocked {
+    my ($io) = @_;
+    return $io->readHDMI(0x07) & 0x80;
+}
+
+sub isFiltersLocked {
+    my ($io) = @_;
+    return $io->isDERegenFilterLocked() && $io->isVertFilterLocked();
+}
+
 sub isLockSTDI {
     my ($io) = @_;
     return $io->readCP(0xb1) & 0x80;
@@ -263,16 +278,36 @@ sub isFreeRun {
 }
 
 # HDMI signal params
+sub getTotalWidth {
+    my ($io) = @_;
+    return $io->readHDMI16(0x1e) & 0x3fff;
+}
+
 sub getWidth {
     my ($io) = @_;
     return $io->readHDMI16(0x07) & 0x1fff;
 }
 
-sub getHeight {
+sub getTotalHeight0 {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x26) & 0x3fff ) / 2;
+}
+
+sub getTotalHeight1 {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x28) & 0x3fff ) / 2;
+}
+
+sub getHeight0 {
     my ($io) = @_;
     return $io->readHDMI16(0x09) & 0x1fff;
 }
 
+sub getHeight1 {
+    my ($io) = @_;
+    return $io->readHDMI16(0x0b) & 0x1fff;
+}
+
 sub getHFrontPorch {
     my ($io) = @_;
     return $io->readHDMI16(0x20) & 0x1fff;
@@ -288,19 +323,34 @@ sub getHBackPorch {
     return $io->readHDMI16(0x24) & 0x1fff;
 }
 
-sub getVFrontPorch {
+sub getVFrontPorch0 {
     my ($io) = @_;
-    return ( $io->readHDMI16(0x2a) & 0x1fff ) / 2;
+    return ( $io->readHDMI16(0x2a) & 0x3fff ) / 2;
 }
 
-sub getVSync {
+sub getVFrontPorch1 {
     my ($io) = @_;
-    return ( $io->readHDMI16(0x2e) & 0x1fff ) / 2;
+    return ( $io->readHDMI16(0x2c) & 0x3fff ) / 2;
 }
 
-sub getVBackPorch {
+sub getVSync0 {
     my ($io) = @_;
-    return ( $io->readHDMI16(0x32) & 0x1fff ) / 2;
+    return ( $io->readHDMI16(0x2e) & 0x3fff ) / 2;
+}
+
+sub getVSync1 {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x30) & 0x3fff ) / 2;
+}
+
+sub getVBackPorch0 {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x32) & 0x3fff ) / 2;
+}
+
+sub getVBackPorch1 {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x34) & 0x3fff ) / 2;
 }
 
 sub getFPS1000 {
@@ -333,8 +383,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.10"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.10" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.10"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.10" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.11"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.11" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.11"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.11" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -342,7 +392,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
